from django.conf import settings
from compressor.filters import CompilerFilter


COMPRESS_AUTOPREFIXER_BINARY = "autoprefixer"
COMPRESS_AUTOPREFIXER_ARGS = ""


class AutoprefixerFilter(CompilerFilter):
    command = "{binary} {args}"
    options = (
        ("binary", getattr(settings, "COMPRESS_AUTOPREFIXER_BINARY", COMPRESS_AUTOPREFIXER_BINARY)),
        ("args", getattr(settings, "COMPRESS_AUTOPREFIXER_ARGS", COMPRESS_AUTOPREFIXER_ARGS)),
    )



from setuptools import setup
import os

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name='django-compressor-autoprefixer',
    version='0.0.2',
    author='Yuri Shikanov',
    author_email='dizballanze@gmail.com',
    packages=['django_compressor_autoprefixer'],
    # scripts=[],
    url='https://github.com/dizballanze/django-compressor-autoprefixer',
    license='MIT',
    description='Django Compressor CSS filter for autoprefixer',
    long_description=read('README.rst'),
    install_requires=[
        "django_compressor",
    ],
    data_files=[('', ['LICENSE', 'README.rst'])]
)
